Function update

pub fn update<'a, Message: Clone + 'static, TopLevelMessage: Clone + 'static>(
    _id: Id,
    event: Event,
    layout: Layout<'_>,
    cursor: Cursor,
    shell: &mut Shell<'_, Message>,
    settings: Option<&Arc<dyn Fn(Rectangle) -> SctkPopupSettings + Send + Sync + 'static>>,
    view: &Arc<dyn Fn() -> Element<'static, Action<TopLevelMessage>> + Send + Sync + 'static>,
    delay: Option<Duration>,
    on_leave: &Message,
    on_surface_action: &dyn Fn(Action) -> Message,
    state: impl FnOnce() -> &'a mut State,
)
Available on crate feature wayland and Linux and crate feature winit only.
Processes the given Event and updates the State of a Tooltip accordingly.